<!---------------------------------------------------------------------------->
## Table of Contents 
- [Introduction](#introduction)
- [DVL Data Fields](#dvl-data-fields)
  - [Fixed Leader Fields](#fixed-leader-fields)
  - [Variable Leader Fields](#variable-leader-fields)
  - [Derived Fields](#derived-fields)
  - [Water Profiling Fields](#water-profiling-fields)
  - [Bottom Track Fields](#bottom-track-fields)
- [Flight Computer Data Fields](#flight-computer-data-fields)

<!---------------------------------------------------------------------------->
## Introduction
This README document describes the contents of the supplementary information section that accompanies the manuscript titled *"Improving resource management for unattended observation of the marginal ice zone using autonomous underwater gliders"* , written by Zachary Duguid and Richard Camilli. This README is written in the Markdown markup language, and is best read via a markdown viewer. The website [StackEdit](https://stackedit.io/) offers a free in-browser markdown editor. 

Two types of files are contained within this directory. First, data files recorded by the DVL Pathfinder Instrument (Teledyne RDI) are described in the [DVL Data Fields](#dvl-data-fields) section. Next, data files recorded by the Slocum Glider Flight Computer (Teledyne Webb Research) are described in the [Flight Computer Data Fields](#flight-computer-data-fields) Section. More detailed information regarding the Pathfinder DVL is available via the *"Pathfinder Doppler Velocity Log (DVL) 600kHz"* user manual by Teledyne Marine, and more detailed information regarding the Slocum Glider Flight Computer is available via the *"Slocum G2 Glider Operators Manual"* manual by Teledyne Webb Research.


<!---------------------------------------------------------------------------->
## DVL Data Fields  
<!---------------------------------------------->
### Fixed Leader Fields 
| Variable Name         | Units | Description                                 |
| ---                   | :---: | ---                                         |
| `system_configuration`|       | Several settings are described here. To parse the information, the numerical value must be converted to binary and then each bit must be decoded. The operating frequency and beam configuration parameters are described here. |
| `num_beams`           |       | Number of beams used to calculate velocity data. The minimum number required to back-out velocity is 3 beams. If four beams are used, the problem becomes over-constrained and the instrument reports an error velocity. |
| `num_bins`            |       | Number of depth bins [0, 255].              |
| `pings_per_ensemble`  |       | Number of pings averaged together in each ensemble. |
| `depth_bin_length`    | [m]   | Length of each depth bin.                   |
| `blanking_distance`   | [m]   | Blanking distance used by Pathfinder to allow ringing effect to recover before processing received data |
| `low_correlation_threshold` | | The minimum threshold of correlation that water-profile data can have to be considered good data |
| `percent_good_minimum`      | | Contains the minimum percentage of water-profiling pings in an ensemble that must be considered good to output velocity data. |
| `error_velocity_threshold`  | [mm/s] | Contains the threshold value used to flag water-current data as good or bad. |
| `coordinate_transformation` | | Several settings are described here. To parse the information, the numerical value must be converted to binary and then each bit must be decoded. Most importantly, the coordinate frame for instrument data is reported here. The coordinate frame is one of: beam coordinates, instrument coordinates, ship coordinates, or Earth coordinates. |
| `heading_alignment`   | [deg] | Contains a correction factor for physical heading misalignment. |
| `heading_bias`        | [deg] | Contains a correction factor for electrical/magnetic heading bias. |
| `sensor_source`       |       | Several settings are described here. To parse the information, the numerical value must be converted to binary and then each bit must be decoded. This field explains were environmental sensor data is coming from. | 
| `bin0_distance`       | [m]   | This field contains the distance to the middle of the first depth bin. This distance is a function of depth bin length, the profiling mode, the blank after transmit distance, and speed of sound. | 
| `transmit_pulse_length` | [m] | Contains the length of the transmit pulse. | 



<!---------------------------------------------->
#### Coordinate Transformation

The meaning of the four coordinate systems are described in the table below. Note that the "beam" coordinates is the most low-level as it does not include any additional processing from the raw values collected, while the "Earth" coordinates contain the most additional processing: the Earth frame account for pitch, roll, and heading alignment of the vehicle when reporting velocity values. 

| Coord Sys | Vel 1     | Vel 2     | Vel 3     | Vel 4     |
| ---       | ---       | ---       | ---       | ---       |
| Beam      | Towards Beam1 | Towards Beam2 | Towards Beam3 | Towards Beam4   |
| Instrument| Beam1-to-Beam2| Beam4-to-Beam3| To Transducer | Error Velocity  |
| Ship      | Port-to-Starboard | Aft-to-Forward| To Surface| Error Velocity  |
| Earth     | To East           | To West   | To Surface    | Error Velocity  |



<!---------------------------------------------->
### Variable Leader Fields 
| Variable Name         | Units | Description                                 |
| ---                   | :---: | ---                                         |
| `time`                | [UTC] | Gives the time at which the ensemble was collected by the Pathfinder DVL. For convenience, the time field is used as the index in the PathfinderTimeSeries DataFrame to make slicing by time-windows easy. |
| `ensemble_number`     |       | Ensemble number for the given data file.    |
| `bit_result`          |       |  Several settings are described here. To parse the information, the numerical value must be converted to binary and then each bit must be decoded. This variable reports the results of the built-in Pathfinder tests. |
| `speed_of_sound`      | [m/s] | Manual or calculated speed of sound.        |
| `depth_of_transducer` | [m]   | Depth below water surface (positive down).  |
| `heading`             | [deg] | Heading angle.                              |
| `pitch`               | [deg] | Pitch angle, positive means vehicle is tilted upwards. | 
| `roll`                | [deg] | Roll angle, positive means glider is banking right. |
| `salinity`            | [ppt] | Salinity measured at the transducer head.   |
| `temperature`         | [C]   | Temperature measured at the transducer head.|
| `pressure`            | [Pa]  | Pressure of water relative to 1 atm.        |



<!---------------------------------------------->
### Derived Fields 
| Variable Name         | Units | Description                                 |
| ---                   | :---: | ---                                         |
| `rel_vel_pressure_u`  | [m/s] | X-component (Eastward) of through water velocity, derived by looking at change in pressure over time and heading reading from compass. |
| `rel_vel_pressure_v`  | [m/s] | Y-component (Northward) of through water velocity, derived by looking at change in pressure over time and heading reading from compass. |
| `rel_vel_dvl_u`       | [m/s] | X-component (Eastward) of through water velocity, given by the DVL. | 
| `rel_vel_dvl_v`       | [m/s] | Y-component (Northward) of through water velocity, given by the DVL. | 
| `abs_vel_btm_u`       | [m/s] | X-component (Eastward) of over ground velocity, given by the DVL operating in bottom-track mode. |
| `abs_vel_btm_v`       | [m/s] | X-component (Eastward) of over ground velocity, given by the DVL operating in bottom-track mode. |
| `abs_vel_w`           | [m/s] | Z-component (Vertical) of glider velocity, given by change in pressure over change in time. |
| `delta_x`             | [m]   | Change in x-component of position since last ensemble. |
| `delta_y`             | [m]   | Change in y-component of position since last ensemble. |
| `delta_z`             | [m]   | Change in z-component of position since last ensemble. |
| `delta_t`             | [s]   | Change in time since last ensemble. |
| `rel_pos_x`           | [m]   | X-component of position relative to given origin point (if unspecified, origin is considered the <0,0,0> point). |
| `rel_pos_y`           | [m]   | Y-component of position relative to given origin point (if unspecified, origin is considered the <0,0,0> point). |
| `rel_pos_z`           | [m]   | Z-component of position relative to given origin point (if unspecified, origin is considered the <0,0,0> point). |
| `origin_x`            | [UTM] | X-component of origin point for defining the relative coordinate frame. |
| `origin_y`            | [UTM] | X-component of origin point for defining the relative coordinate frame. |
| `angle_of_attack`     | [deg] | Angle of attack of the glider, currently assumed to be zero for simplicity. |


<!---------------------------------------------->
### Water Profiling Fields 

Note that the interpretation of the water-profiling fields is dependent on the coordinate transformation being used. For example, in Earth coordinates the first beam (`vel_bin#_beam0`) refers to the Eastward velocity component and the second beam (`vel_bin#_beam1`) refers to the Northward velocity component. It is also important to note that the data fields are indexed from zero while the physical beams are indexed from 1. 

| Variable Name         | Units | Description                                 |
| ---                   | :---: | ---                                         |
| `vel_bin#_beam#`      | [m/s] | Velocity.                                   |
| `cor_bin#_beam#`      |       | Linear scale of correlation magnitude (255 = best). |
| `ech_bin#_beam#`      | [dB]  | Echo intensity                              |
| `per_bin#_beam#`      |       | Percent good data quality indicator.        |


<!---------------------------------------------->
### Bottom Track Fields 
| Variable Name               | Units | Description | 
| ---                         | :---: | --- |
| `btm_beam#_range`           | [m]   | Bottom track vertical range (NOT slant range) to the detected bottom, does not take into account the effects of pitch and roll. A value of zero indicates that the bottom was not detected. |
| `btm_beam#_velocity`        | [m/s] | Bottom track velocity, meaning depends on `coordinate_transformation`. |
| `btm_beam#_rssi`            | [dB]  | Receiver Signal Strength Indicator (RSSI) value in the center of the bottom echo for each beam. |
| `btm_pings_per_ensemble`    |       | Number of pings averaged together per ensemble. |
| `btm_bottom_track_mode`     |       | Bottom-tracking mode.  |
| `btm_max_error_velocity`    | [m/s] | Maximum error velocity | 


<!---------------------------------------------------------------------------->
## Flight Computer Data Fields
The following data fields are extracted from the flight computer of the Slocum Glider, corresponding with the `2019-Nov-Slocum-Flight-Computer.csv` included in this supplementary information section. The units and a brief description of each variable is shown in the table below. LMC stands for Local Mission Coordinates. More detailed information regarding the Slocum Glider flight computer is available from the *"Slocum G2 Glider Operators Manual"*, by Teledyne Webb Research.

| Variable Name             | Units | Description | 
| --- | --- | --- |
| `m_present_time`  | [s]   | Time since 1970. |
| `m_speed`         | [m/s] | Horizontal through water speed. |
| `m_pitch`         | [rad] | Pitch of the vehicle, >0 means nose up. |
| `m_roll`          | [rad] | Roll of the vehicle, >0 means port wing up. |
| `m_heading`       | [rad] | Heading of the glider. |
| `m_fin`           | [rad] | Angular position of the tail fin. |
| `m_depth`         | [m]   | Depth of the vehicle. |
| `m_depth_rate`    | [m/s] | Depth rate of the vehicle. |
| `m_water_depth`   | [m]   | Vehicle depth plus altitude of vehicle. |
| `m_pressure`      | [bar] | Pressure measured by the vehicle. |
| `m_altitude`      | [m]   | Height above seafloor. |
| `m_battery`       | [V]   | Average battery voltage. |
| `m_vacuum`        | [inHg]| Internal glider pressure. |
| `c_pitch`         | [rad] | Commanded pitch. |
| `c_roll`          | [rad] | Commanded roll. |
| `c_heading`       | [rad] | Commanded heading. |
| `c_fin`           | [rad] | Commanded fin position, >0 vehicle turns right. |
| `m_gps_x_lmc`     | [m]   | GPS position in LMC. |
| `m_gps_y_lmc`     | [m]   | GPs position in LMC. |
| `m_gps_fix_x_lmc` | [m]   | Location of first GPS position fix in LMC. |
| `m_gps_fix_y_lmc` | [m]   | Location of first GPS position fix in LMC. |
| `m_gps_status`    |       | Updated status of the GPS. |
| `m_x_lmc`         | [m]   | Waypoint location in LMC. |
| `m_y_lmc`         | [m]   | Waypoint location in LMC. |
| `m_dr_time`       | [s]   | Time glider has been underwater since last surface.|
| `m_dr_surf_x_lmc` | [m]   | Dead-reckoned surface location in LMC. |
| `m_dr_surf_y_lmc` | [m]   | Dead-reckoned surface location in LMC. |
| `m_ext_x_lmc`     | [m]   | Vehicle position from external navigation unit. |
| `m_ext_y_lmc`     | [m]   | Vehicle position from external navigation unit. |
| `m_ext_z_lmc`     | [m]   | Vehicle position from external navigation unit. |
| `x_lmc_xy_source` |       | Explains how LMC position was computed. Could be from GPS, dead-reckoned, initiated to zero, or not computed during this cycle.|
| `c_wpt_x_lmc`     | [m]   | Commanded waypoint in LMC coordinates. |
| `c_wpt_y_lmc`     | [m]   | Commanded waypoint in LMC coordinates. |
| `m_lat`           | [deg] | Vehicle position in terms of latitude. |
| `m_lon`           | [deg] | Vehicle position in terms of longitude. |
| `m_gps_lat`       | [deg] | Latitude in DDMM.MMMM format, >0 in the North. |
| `m_gps_lon`       | [deg] | Longitude in DDMM.MMMM format, >0 in the East. |
| `m_water_vx`      | [m/s] | Water speed in LMC. |
| `m_water_vy`      | [m/s] | Water speed in LMC. |
| `m_vx_lmc`        | [m/s] | Horizontal speed over ground, in LMC. |
| `m_vy_lmc`        | [m/s] | Horizontal speed over ground, in LMC. |
| `m_appear_to_be_at_surface` | [bool] | True if glider appears to be at surface. |
| `m_science_clothesline_lag` | [s]    | Time lag between flight computer and science computer. |
| `sci_m_present_time` |        [s]    | Seconds since 1970. |
| `x_software_ver` |                   | Current software version. | 
